==> gramps_2.2.3.orig.tar.gz: gramps-2.2.3/src/DisplayTabs/_NameEmbedList.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2000-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _NameEmbedList.py 7268 2006-08-26 04:29:20Z dallingham $

#-------------------------------------------------------------------------
#
# Python classes
#
#-------------------------------------------------------------------------
import gtk

#-------------------------------------------------------------------------
#
# Python classes
#
#-------------------------------------------------------------------------
from gettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS classes
#
#-------------------------------------------------------------------------
import RelLib
import Errors
from DdTargets import DdTargets
from _NameModel import NameModel
from _EmbeddedList import EmbeddedList

#-------------------------------------------------------------------------
#
# 
#
#-------------------------------------------------------------------------
class NameEmbedList(EmbeddedList):

    _HANDLE_COL = 2
    _DND_TYPE   = DdTargets.NAME

    _column_names = [
        (_('Name'), 0, 250), 
        (_('Type'), 1, 100), 
        ]
    
    def __init__(self, dbstate, uistate, track, data, person, callback):
        self.data = data
        self.person = person
        self.callback = callback
        
        EmbeddedList.__init__(self, dbstate, uistate, track, 
                              _('Names'), NameModel)

    def get_data(self):
        return self.data

    def column_order(self):
        return ((1, 0), (1, 1))

    def get_popup_menu_items(self):
        return [
            (True, gtk.STOCK_ADD, self.add_button_clicked),
            (True, gtk.STOCK_EDIT, self.edit_button_clicked),
            (True, gtk.STOCK_REMOVE, self.del_button_clicked),
            (False, _('Set as default name'), self.name_button_clicked),
            ]

    def name_button_clicked(self, obj):
        name = self.get_selected()
        pname = self.person.get_primary_name()
        if name:
            self.person.set_primary_name(name)
            self.data.remove(name)
            self.data.append(pname)
        self.rebuild()
        self.callback()
        
    def add_button_clicked(self, obj):
        name = RelLib.Name()
        try:
            from Editors import EditName
            
            EditName(self.dbstate, self.uistate, self.track, 
                     name, self.add_callback)
        except Errors.WindowActiveError:
            pass

    def add_callback(self, name):
        self.get_data().append(name)
        self.rebuild()

    def edit_button_clicked(self, obj):
        name = self.get_selected()
        if name:
            try:
                from Editors import EditName
                
                EditName(self.dbstate, self.uistate, self.track, 
                         name, self.edit_callback)
            except Errors.WindowActiveError:
                pass

    def edit_callback(self, name):
        self.rebuild()

==> gramps_3.0.1.orig.tar.gz: gramps-3.0.1/src/DisplayTabs/_NameEmbedList.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2000-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _NameEmbedList.py 10108 2008-02-24 18:58:45Z acraphae $

#-------------------------------------------------------------------------
#
# Python classes
#
#-------------------------------------------------------------------------
import gtk

#-------------------------------------------------------------------------
#
# Python classes
#
#-------------------------------------------------------------------------
from gettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS classes
#
#-------------------------------------------------------------------------
import gen.lib
import Errors
from DdTargets import DdTargets
from DisplayTabs._NameModel import NameModel
from DisplayTabs._EmbeddedList import EmbeddedList

#-------------------------------------------------------------------------
#
# 
#
#-------------------------------------------------------------------------
class NameEmbedList(EmbeddedList):

    _HANDLE_COL = 2
    _DND_TYPE   = DdTargets.NAME

    _MSG = {
        'add'   : _('Create and add a new name'),
        'del'   : _('Remove the existing name'),
        'edit'  : _('Edit the selected name'),
        'up'    : _('Move the selected name upwards'),
        'down'  : _('Move the selected name downwards'),
    }

    _column_names = [
        (_('Name'), 0, 250), 
        (_('Type'), 1, 100), 
        ]
    
    def __init__(self, dbstate, uistate, track, data, person, callback):
        self.data = data
        self.person = person
        self.callback = callback
        
        EmbeddedList.__init__(self, dbstate, uistate, track, _('_Names'), 
                              NameModel, move_buttons=True)

    def get_data(self):
        return self.data

    def column_order(self):
        return ((1, 0), (1, 1))

    def get_popup_menu_items(self):
        return [
            (True, True, gtk.STOCK_ADD, self.add_button_clicked),
            (False,True, gtk.STOCK_EDIT, self.edit_button_clicked),
            (True, True, gtk.STOCK_REMOVE, self.del_button_clicked),
            (True, False, _('Set as default name'), self.name_button_clicked),
            ]

    def name_button_clicked(self, obj):
        name = self.get_selected()
        pname = self.person.get_primary_name()
        if name:
            self.person.set_primary_name(name)
            self.data.remove(name)
            self.data.append(pname)
        self.rebuild()
        self.callback()
        
    def add_button_clicked(self, obj):
        name = gen.lib.Name()
        try:
            from Editors import EditName
            
            EditName(self.dbstate, self.uistate, self.track, 
                     name, self.add_callback)
        except Errors.WindowActiveError:
            pass

    def add_callback(self, name):
        self.get_data().append(name)
        self.rebuild()

    def edit_button_clicked(self, obj):
        name = self.get_selected()
        if name:
            try:
                from Editors import EditName
                
                EditName(self.dbstate, self.uistate, self.track, 
                         name, self.edit_callback)
            except Errors.WindowActiveError:
                pass

    def edit_callback(self, name):
        self.rebuild()
